#!/bin/bash

# spdx-license-identifier: gpl-3.0-only
# Copyright (C) 2022 Michał Góral

[[ -n "${LIBGPAK_BUILD_DOCKER_SH:-}" ]] && return
LIBGPAK_BUILD_DOCKER_SH=1

source "${LIBRARY}/message.sh"
source "${LIBRARY}/spinner.sh"

gen_docker() {
    local infile="$1"
    local outfile="$2"
    local distribution="$3"
}

build_docker() {
    local codename="$1"
    local outcontext="${BUILD_DIR}/${codename}/.docker"
    local tag="gpak:${codename}"
    local flags=(
        --build-arg "CODENAME=${codename}"
        --build-arg "UID=$(id -u)"
        --tag "${tag}"
    )

    rm -rf "${outcontext}"
    mkdir -p "$(dirname -- "${outcontext}")"
    cp -r "${CONTEXT}" "${outcontext}"

    ${ENGINE} build "${outcontext}" "${flags[@]}"
}

build_docker_images() {
    for codename in "$@"; do
        spinmsg "Building %s image" "${codename}"
        spinner build_docker "$codename"
        [[ $? -ne 0 ]] && return 1
    done
    return 0
}
